## v0.2.0 (2025-02-23)

- Add `typing_objects.is_deprecated()` by @Viicos in [#24](https://github.com/pydantic/typing-inspection/pull/24)
- Add missing positional only parameter markers in `typing_objects` stub file by @Viicos in [#23](https://github.com/pydantic/typing-inspection/pull/23)
- Add project URLs by @Viicos in [#22](https://github.com/pydantic/typing-inspection/pull/22)

## v0.1.0 (2025-02-22)

Initial release.
